summaryrefslogtreecommitdiffstats
path: root/kcontrol/componentchooser/componentchooser.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 10:49:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 10:49:49 -0600
commitdc5f267664506a312203c26bfe9001a448b0bb0f (patch)
treea78c7f15e87303d22b89619db42fc56ad8f4a046 /kcontrol/componentchooser/componentchooser.cpp
parent98f4a055baf6eb7ea5c3d69d6a3f2162b491e253 (diff)
downloadtdebase-dc5f267664506a312203c26bfe9001a448b0bb0f.tar.gz
tdebase-dc5f267664506a312203c26bfe9001a448b0bb0f.zip
Rename KLock and KTrader to avoid conflicts with KDE4
Diffstat (limited to 'kcontrol/componentchooser/componentchooser.cpp')
-rw-r--r--kcontrol/componentchooser/componentchooser.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcontrol/componentchooser/componentchooser.cpp b/kcontrol/componentchooser/componentchooser.cpp
index 8eab27216..c66a28b06 100644
--- a/kcontrol/componentchooser/componentchooser.cpp
+++ b/kcontrol/componentchooser/componentchooser.cpp
@@ -62,7 +62,7 @@ void CfgComponent::slotComponentChanged(const TQString&) {
}
void CfgComponent::save(TDEConfig *cfg) {
// yes, this can happen if there are NO KTrader offers for this component
if (!m_lookupDict[ComponentSelector->currentText()])
return;
@@ -84,9 +84,9 @@ void CfgComponent::load(TDEConfig *cfg) {
TQString ServiceTypeToConfigure=cfg->readEntry("ServiceTypeToConfigure");
TQString MimeTypeOfInterest=cfg->readEntry("MimeTypeOfInterest");
- KTrader::OfferList offers = KTrader::self()->query(MimeTypeOfInterest, "'"+ServiceTypeToConfigure+"' in ServiceTypes");
+ TDETrader::OfferList offers = TDETrader::self()->query(MimeTypeOfInterest, "'"+ServiceTypeToConfigure+"' in ServiceTypes");
- for (KTrader::OfferList::Iterator tit = offers.begin(); tit != offers.end(); ++tit)
+ for (TDETrader::OfferList::Iterator tit = offers.begin(); tit != offers.end(); ++tit)
{
ComponentSelector->insertItem((*tit)->name());
m_lookupDict.insert((*tit)->name(),new TQString((*tit)->desktopEntryName()));
@@ -62,7 +62,7 @@ void CfgComponent::slotComponentChanged(const TQString&) {
}
void CfgComponent::save(TDEConfig *cfg) {
- // yes, this can happen if there are NO KTrader offers for this component
+ // yes, this can happen if there are NO TDETrader offers for this component
if (!m_lookupDict[ComponentSelector->currentText()])
return;